@@ -222,7 +222,7 @@ class RestModel(MethodView):
                         else:
                             v = None
                     if isinstance(v, dict) or isinstance(v, list):
-                        v = self._json_to_str(v)
+                        v = json.dumps(v) if v else None
                     setattr(obj, k, v)
         return obj
 
@@ -236,11 +236,6 @@ class RestModel(MethodView):
                 value = parse(value).time()
         return value
 
-    def _json_to_str(self, obj):
-        if obj and isinstance(obj, dict):
-            return json.dumps(obj)
-        return obj
-
     def _str_to_json(self, text):
         try:
             return json.loads(text)
